===== 
log_config 
===== 
Description 
-------- 
Provide a function  for anyone who want to configure log parameters easily,
just call init_log_config before your use the module of logging that build-in python3
